package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcContractPayment;

/**
 * cmc合同回款Service接口
 * 
 * @author cmc
 * @date 2024-04-19
 */
public interface ICmcContractPaymentService 
{
    /**
     * 查询cmc合同回款
     * 
     * @param contractId cmc合同回款主键
     * @return cmc合同回款
     */
    public List<CmcContractPayment> selectCmcContractPaymentByContractId(String contractId);

    /**
     * 查询cmc合同回款列表
     * 
     * @param cmcContractPayment cmc合同回款
     * @return cmc合同回款集合
     */
    public List<CmcContractPayment> selectCmcContractPaymentList(CmcContractPayment cmcContractPayment);

    /**
     * 新增cmc合同回款
     * 
     * @param cmcContractPayment cmc合同回款
     * @return 结果
     */
    public int insertCmcContractPayment(CmcContractPayment cmcContractPayment);

    /**
     * 修改cmc合同回款
     * 
     * @param cmcContractPayment cmc合同回款
     * @return 结果
     */
    public int updateCmcContractPayment(CmcContractPayment cmcContractPayment);

    /**
     * 批量删除cmc合同回款
     * 
     * @param contractIds 需要删除的cmc合同回款主键集合
     * @return 结果
     */
    public int deleteCmcContractPaymentByContractIds(String[] contractIds);

    /**
     * 删除cmc合同回款信息
     * 
     * @param contractId cmc合同回款主键
     * @return 结果
     */
    public int deleteCmcContractPaymentByContractId(String contractId);
}
